.onAttach <- function( libname, pkgname ){
	# placeholder
}

